@@ -665,11 +665,11 @@ process_numeric (session * sess, int n,
 		else
 			EMIT_SIGNAL_TIMESTAMP (XP_TE_CHANMODES, sess, word[4], word_eol[5],
 										  NULL, NULL, 0, tags_data->timestamp);
+		fe_update_mode_buttons (sess, 'c', '-');
+		fe_update_mode_buttons (sess, 'r', '-');
 		fe_update_mode_buttons (sess, 't', '-');
 		fe_update_mode_buttons (sess, 'n', '-');
-		fe_update_mode_buttons (sess, 's', '-');
 		fe_update_mode_buttons (sess, 'i', '-');
-		fe_update_mode_buttons (sess, 'p', '-');
 		fe_update_mode_buttons (sess, 'm', '-');
 		fe_update_mode_buttons (sess, 'l', '-');
 		fe_update_mode_buttons (sess, 'k', '-');
@@ -968,6 +968,9 @@ process_numeric (session * sess, int n,
 			tcp_send_len (serv, "CAP END\r\n", 9);
 		}
 		break;
+	case 908:	/* Supported SASL Mechs */
+		inbound_sasl_supportedmechs (serv, word[4]);
+		break;
 
 	default:
 
@@ -1039,8 +1042,12 @@ process_named_msg (session *sess, char *type, char *word[], char *word_eol[],
 			{
 				char *chan = word[3];
 				char *account = word[4];
-				char *realname = word_eol[5] + 1;
+				char *realname = word_eol[5];
 
+				if (account && strcmp (account, "*") == 0)
+					account = NULL;
+				if (realname && *realname == ':')
+					realname++;
 				if (*chan == ':')
 					chan++;
 				if (!serv->p_cmp (nick, serv->nick))
@@ -1068,8 +1075,14 @@ process_named_msg (session *sess, char *type, char *word[], char *word_eol[],
 			return;
 
 		case WORDL('K','I','L','L'):
-			EMIT_SIGNAL_TIMESTAMP (XP_TE_KILL, sess, nick, word_eol[5], NULL, NULL,
-										  0, tags_data->timestamp);
+			{
+				char *reason = word_eol[4];
+				if (*reason == ':')
+					reason++;
+
+				EMIT_SIGNAL_TIMESTAMP (XP_TE_KILL, sess, nick, reason, NULL, NULL,
+											  0, tags_data->timestamp);
+			}
 			return;
 
 		case WORDL('M','O','D','E'):
@@ -1197,7 +1210,8 @@ process_named_msg (session *sess, char *type, char *word[], char *word_eol[],
 				if (*to)
 				{
 					/* Handle limited channel messages, for now no special event */
-					if (strchr (serv->nick_prefixes, to[0]) != NULL)
+					if (strchr (serv->chantypes, to[0]) == NULL
+						&& strchr (serv->nick_prefixes, to[0]) != NULL)
 						to++;
 						
 					text = word_eol[4];
@@ -1502,9 +1516,6 @@ irc_inline (server *serv, char *buf, int len)
 
 	if (buf[0] == ':')
 	{
-		int eat1;
-		int eat2;
-
 		/* find a context for this message */
 		if (is_channel (serv, word[3]))
 		{
@@ -1519,11 +1530,8 @@ irc_inline (server *serv, char *buf, int len)
 		word[0] = type;
 		word_eol[1] = buf;	/* keep the ":" for plugins */
 
-		eat1 = plugin_emit_server (sess, type, word, word_eol);
-		eat2 = plugin_emit_server_attrs (sess, type, word, word_eol, 
-										 tags_data.timestamp);
-
-		if (eat1 || eat2)
+		if (plugin_emit_server (sess, type, word, word_eol,
+								tags_data.timestamp))
 			goto xit;
 
 		word[1]++;
@@ -1531,16 +1539,10 @@ irc_inline (server *serv, char *buf, int len)
 
 	} else
 	{
-		int eat1;
-		int eat2;
-
 		word[0] = type = word[1];
 
-		eat1 = plugin_emit_server (sess, type, word, word_eol);
-		eat2 = plugin_emit_server_attrs (sess, type, word, word_eol,
-										 tags_data.timestamp);
-
-		if (eat1 || eat2)
+		if (plugin_emit_server (sess, type, word, word_eol,
+								tags_data.timestamp))
 			goto xit;
 	}
 
