@@ -436,30 +436,30 @@ expand_homedir (char *file)
 	char *ret, *user;
 	struct passwd *pw;
 
-	if (*file == '~')
+	if (file[0] == '~')
 	{
-		if (file[1] != '\0' && file[1] != '/')
-		{
-			user = strdup(file);
-			if (strchr(user,'/') != NULL)
-				*(strchr(user,'/')) = '\0';
-			if ((pw = getpwnam(user + 1)) == NULL)
-			{
-				free(user);
-				return strdup(file);
-			}
-			free(user);
-			user = strchr(file, '/') != NULL ? strchr(file,'/') : file;
-			ret = malloc(strlen(user) + strlen(pw->pw_dir) + 1);
-			strcpy(ret, pw->pw_dir);
-			strcat(ret, user);
-		}
+		if (file[1] == '\0' || file[1] == '/')
+			return g_strconcat (g_get_home_dir (), &file[1], NULL);
+
+		char *slash_pos;
+
+		user = g_strdup(file);
+
+		slash_pos = strchr(user, '/');
+		if (slash_pos != NULL)
+			*slash_pos = '\0';
+
+		pw = getpwnam(user + 1);
+		g_free(user);
+
+		if (pw == NULL)
+			return g_strdup(file);
+
+		slash_pos = strchr(file, '/');
+		if (slash_pos == NULL)
+			return g_strdup (pw->pw_dir);
 		else
-		{
-			ret = malloc (strlen (file) + strlen (g_get_home_dir ()) + 1);
-			sprintf (ret, "%s%s", g_get_home_dir (), file + 1);
-		}
-		return ret;
+			return g_strconcat (pw->pw_dir, slash_pos, NULL);
 	}
 #endif
 	return g_strdup (file);
@@ -1893,7 +1893,8 @@ unity_mode ()
 {
 #ifdef G_OS_UNIX
 	const char *env = g_getenv("XDG_CURRENT_DESKTOP");
-	if (env && strcmp (env, "Unity") == 0)
+	if (env && (strcmp (env, "Unity") == 0
+			|| strcmp (env, "Pantheon") == 0))
 		return 1;
 #endif
 	return 0;
