@@ -587,12 +587,12 @@ servlist_net_keypress_cb (GtkWidget *wid, GdkEventKey *evt, gpointer tree)
 
 	if (evt->state & STATE_SHIFT)
 	{
-		if (evt->keyval == GDK_Up)
+		if (evt->keyval == GDK_KEY_Up)
 		{
 			handled = TRUE;
 			network_list = servlist_move_item (GTK_TREE_VIEW (tree), network_list, selected_net, -1);
 		}
-		else if (evt->keyval == GDK_Down)
+		else if (evt->keyval == GDK_KEY_Down)
 		{
 			handled = TRUE;
 			network_list = servlist_move_item (GTK_TREE_VIEW (tree), network_list, selected_net, +1);
@@ -671,10 +671,10 @@ servlist_update_from_entry (char **str, GtkWidget *entry)
 	if (*str)
 		free (*str);
 
-	if (GTK_ENTRY (entry)->text[0] == 0)
+	if (gtk_entry_get_text (GTK_ENTRY (entry))[0] == 0)
 		*str = NULL;
 	else
-		*str = strdup (GTK_ENTRY (entry)->text);
+		*str = strdup (gtk_entry_get_text (GTK_ENTRY (entry)));
 }
 
 static void
@@ -944,22 +944,30 @@ static int
 servlist_savegui (void)
 {
 	char *sp;
+	const char *nick1, *nick2;
 
 	/* check for blank username, ircd will not allow this */
-	if (GTK_ENTRY (entry_guser)->text[0] == 0)
+	if (gtk_entry_get_text (GTK_ENTRY (entry_guser))[0] == 0)
 		return 1;
 
-	/* if (GTK_ENTRY (entry_greal)->text[0] == 0)
+	/* if (gtk_entry_get_text (GTK_ENTRY (entry_greal))[0] == 0)
 		return 1; */
 
-	strcpy (prefs.hex_irc_nick1, GTK_ENTRY (entry_nick1)->text);
-	strcpy (prefs.hex_irc_nick2, GTK_ENTRY (entry_nick2)->text);
-	strcpy (prefs.hex_irc_nick3, GTK_ENTRY (entry_nick3)->text);
-	strcpy (prefs.hex_irc_user_name, GTK_ENTRY (entry_guser)->text);
+	nick1 = gtk_entry_get_text (GTK_ENTRY (entry_nick1));
+	nick2 = gtk_entry_get_text (GTK_ENTRY (entry_nick2));
+
+	/* ensure unique nicknames */
+	if (!rfc_casecmp (nick1, nick2))
+		return 2;
+
+	strcpy (prefs.hex_irc_nick1, nick1);
+	strcpy (prefs.hex_irc_nick2, nick2);
+	strcpy (prefs.hex_irc_nick3, gtk_entry_get_text (GTK_ENTRY (entry_nick3)));
+	strcpy (prefs.hex_irc_user_name, gtk_entry_get_text (GTK_ENTRY (entry_guser)));
 	sp = strchr (prefs.hex_irc_user_name, ' ');
 	if (sp)
 		sp[0] = 0;	/* spaces will break the login */
-	/* strcpy (prefs.hex_irc_real_name, GTK_ENTRY (entry_greal)->text); */
+	/* strcpy (prefs.hex_irc_real_name, gtk_entry_get_text (GTK_ENTRY (entry_greal))); */
 	servlist_save ();
 	save_config (); /* For nicks stored in hexchat.conf */
 
@@ -1030,12 +1038,12 @@ servlist_keypress_cb (GtkWidget *wid, GdkEventKey *evt, GtkNotebook *notebook)
 
 	if (evt->state & STATE_SHIFT)
 	{
-		if (evt->keyval == GDK_Up)
+		if (evt->keyval == GDK_KEY_Up)
 		{
 			handled = TRUE;
 			delta = -1;
 		}
-		else if (evt->keyval == GDK_Down)
+		else if (evt->keyval == GDK_KEY_Down)
 		{
 			handled = TRUE;
 			delta = +1;
@@ -1080,8 +1088,11 @@ servlist_autojoinedit (ircnet *net, char *channel, gboolean add)
 	else
 	{
 		fav = servlist_favchan_find (net, channel, NULL);
-		servlist_favchan_remove (net, fav);
-		servlist_save ();
+		if (fav)
+		{
+			servlist_favchan_remove (net, fav);
+			servlist_save ();
+		}
 	}
 }
 
@@ -1104,12 +1115,15 @@ servlist_toggle_global_user (gboolean sensitive)
 static void
 servlist_connect_cb (GtkWidget *button, gpointer userdata)
 {
+	int servlist_err;
+
 	if (!selected_net)
 		return;
 
-	if (servlist_savegui () != 0)
+	servlist_err = servlist_savegui ();
+	if (servlist_err == 1)
 	{
-		fe_message (_("User name and Real name cannot be left blank."), FE_MSG_ERROR);
+		fe_message (_("User name cannot be left blank."), FE_MSG_ERROR);
 		return;
 	}
 
@@ -1208,13 +1222,13 @@ servlist_check_cb (GtkWidget *but, gpointer num_p)
 	if ((1 << num) == FLAG_CYCLE || (1 << num) == FLAG_USE_PROXY)
 	{
 		/* these ones are reversed, so it's compat with 2.0.x */
-		if (GTK_TOGGLE_BUTTON (but)->active)
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (but)))
 			selected_net->flags &= ~(1 << num);
 		else
 			selected_net->flags |= (1 << num);
 	} else
 	{
-		if (GTK_TOGGLE_BUTTON (but)->active)
+		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (but)))
 			selected_net->flags |= (1 << num);
 		else
 			selected_net->flags &= ~(1 << num);
@@ -1222,7 +1236,7 @@ servlist_check_cb (GtkWidget *but, gpointer num_p)
 
 	if ((1 << num) == FLAG_USE_GLOBAL)
 	{
-		servlist_toggle_global_user (!GTK_TOGGLE_BUTTON (but)->active);
+		servlist_toggle_global_user (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (but)));
 	}
 }
 
@@ -1255,7 +1269,7 @@ servlist_create_entry (GtkWidget *table, char *labeltext, int row,
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
 
 	entry = gtk_entry_new ();
-	add_tip (entry, tip);
+	gtk_widget_set_tooltip_text (entry, tip);
 	gtk_widget_show (entry);
 	gtk_entry_set_text (GTK_ENTRY (entry), def ? def : "");
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), entry);
@@ -1496,7 +1510,7 @@ servlist_combo_cb (GtkEntry *entry, gpointer userdata)
 
 	if (selected_net->encoding)
 		free (selected_net->encoding);
-	selected_net->encoding = strdup (entry->text);
+	selected_net->encoding = strdup (gtk_entry_get_text (entry));
 }
 
 /* Fills up the network's authentication type so that it's guaranteed to be either NULL or a valid value. */
@@ -1531,6 +1545,46 @@ servlist_logintypecombo_cb (GtkComboBox *cb, gpointer *userdata)
 		gtk_widget_set_sensitive (edit_entry_pass, TRUE);
 }
 
+static void
+servlist_username_changed_cb (GtkEntry *entry, gpointer userdata)
+{
+	GtkWidget *connect_btn = GTK_WIDGET (userdata);
+
+	if (gtk_entry_get_text (entry)[0] == 0)
+	{
+		gtk_entry_set_icon_from_stock (entry, GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_DIALOG_ERROR);
+		gtk_entry_set_icon_tooltip_text (entry, GTK_ENTRY_ICON_SECONDARY,
+										_("User name cannot be left blank."));
+		gtk_widget_set_sensitive (connect_btn, FALSE);
+	}
+	else
+	{
+		gtk_entry_set_icon_from_stock (entry, GTK_ENTRY_ICON_SECONDARY, NULL);
+		gtk_widget_set_sensitive (connect_btn, TRUE);
+	}
+}
+
+static void
+servlist_nick_changed_cb (GtkEntry *entry, gpointer userdata)
+{
+	GtkWidget *connect_btn = GTK_WIDGET (userdata);
+	const gchar *nick1 = gtk_entry_get_text (GTK_ENTRY (entry_nick1));
+	const gchar *nick2 = gtk_entry_get_text (GTK_ENTRY (entry_nick2));
+
+	if (!rfc_casecmp (nick1, nick2))
+	{
+		gtk_entry_set_icon_from_stock (entry, GTK_ENTRY_ICON_SECONDARY, GTK_STOCK_DIALOG_ERROR);
+		gtk_entry_set_icon_tooltip_text (entry, GTK_ENTRY_ICON_SECONDARY,
+										_("You must have two unique nick names."));
+		gtk_widget_set_sensitive (connect_btn, FALSE);
+	}
+	else
+	{
+		gtk_entry_set_icon_from_stock (GTK_ENTRY(entry_nick1), GTK_ENTRY_ICON_SECONDARY, NULL);
+		gtk_entry_set_icon_from_stock (GTK_ENTRY(entry_nick2), GTK_ENTRY_ICON_SECONDARY, NULL);
+		gtk_widget_set_sensitive (connect_btn, TRUE);
+	}
+}
 
 static GtkWidget *
 servlist_create_charsetcombo (void)
@@ -1549,7 +1603,7 @@ servlist_create_charsetcombo (void)
 
 	gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN(cb))), selected_net->encoding ? selected_net->encoding : "System default");
 	
-	g_signal_connect (G_OBJECT (GTK_BIN (cb)->child), "changed",
+	g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (cb))), "changed",
 							G_CALLBACK (servlist_combo_cb), NULL);
 
 	return cb;
@@ -1573,7 +1627,7 @@ servlist_create_logintypecombo (GtkWidget *data)
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (cb), servlist_get_login_desc_index (selected_net->logintype));
 
-	add_tip (cb, _("The way you identify yourself to the server. For custom login methods use connect commands."));
+	gtk_widget_set_tooltip_text (cb, _("The way you identify yourself to the server. For custom login methods use connect commands."));
 	g_signal_connect (G_OBJECT (GTK_BIN (cb)), "changed", G_CALLBACK (servlist_logintypecombo_cb), data);
 
 	return cb;
@@ -1582,7 +1636,7 @@ servlist_create_logintypecombo (GtkWidget *data)
 static void
 no_servlist (GtkWidget * igad, gpointer serv)
 {
-	if (GTK_TOGGLE_BUTTON (igad)->active)
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (igad)))
 		prefs.hex_gui_slist_skip = TRUE;
 	else
 		prefs.hex_gui_slist_skip = FALSE;
@@ -1591,7 +1645,7 @@ no_servlist (GtkWidget * igad, gpointer serv)
 static void
 fav_servlist (GtkWidget * igad, gpointer serv)
 {
-	if (GTK_TOGGLE_BUTTON (igad)->active)
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (igad)))
 		prefs.hex_gui_slist_fav = TRUE;
 	else
 		prefs.hex_gui_slist_fav = FALSE;
@@ -1650,7 +1704,6 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 	snprintf (buf, sizeof (buf), _(DISPLAY_NAME": Edit %s"), net->name);
 	gtk_window_set_title (GTK_WINDOW (editwindow), buf);
 	gtk_window_set_default_size (GTK_WINDOW (editwindow), netedit_win_width, netedit_win_height);
-	gtk_window_set_position (GTK_WINDOW (editwindow), GTK_WIN_POS_MOUSE);
 	gtk_window_set_transient_for (GTK_WINDOW (editwindow), GTK_WINDOW (parent));
 	gtk_window_set_modal (GTK_WINDOW (editwindow), TRUE);
 	gtk_window_set_type_hint (GTK_WINDOW (editwindow), GDK_WINDOW_TYPE_HINT_DIALOG);
@@ -1683,7 +1736,7 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolledwindow5), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolledwindow5), GTK_SHADOW_IN);
-	add_tip (scrolledwindow5, _("%n=Nick name\n%p=Password\n%r=Real name\n%u=User name"));
+	gtk_widget_set_tooltip_text (scrolledwindow5, _("%n=Nick name\n%p=Password\n%r=Real name\n%u=User name"));
 
 
 	/* Server Tree */
@@ -1711,7 +1764,6 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 								"editable", 1,
 								NULL);
 
-
 	/* Channel Tree */
 	store = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_BOOLEAN);
 	model = GTK_TREE_MODEL (store);
@@ -1784,19 +1836,19 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 	g_signal_connect (G_OBJECT (buttonadd), "clicked",
 							G_CALLBACK (servlist_addbutton_cb), notebook);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox1), buttonadd);
-	GTK_WIDGET_SET_FLAGS (buttonadd, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (buttonadd, TRUE);
 
 	buttonremove = gtk_button_new_from_stock ("gtk-remove");
 	g_signal_connect (G_OBJECT (buttonremove), "clicked",
 							G_CALLBACK (servlist_deletebutton_cb), notebook);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox1), buttonremove);
-	GTK_WIDGET_SET_FLAGS (buttonremove, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (buttonremove, TRUE);
 
 	buttonedit = gtk_button_new_with_mnemonic (_("_Edit"));
 	g_signal_connect (G_OBJECT (buttonedit), "clicked",
 							G_CALLBACK (servlist_editbutton_cb), notebook);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox1), buttonedit);
-	GTK_WIDGET_SET_FLAGS (buttonedit, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (buttonedit, TRUE);
 
 
 	/* Checkboxes and entries */
@@ -1806,7 +1858,7 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 	gtk_table_set_col_spacings (GTK_TABLE (table3), 8);
 
 	check = servlist_create_check (0, !(net->flags & FLAG_CYCLE), table3, 0, 0, _("Connect to selected server only"));
-	add_tip (check, _("Don't cycle through all the servers when the connection fails."));
+	gtk_widget_set_tooltip_text (check, _("Don't cycle through all the servers when the connection fails."));
 	servlist_create_check (3, net->flags & FLAG_AUTO_CONNECT, table3, 1, 0, _("Connect to this network automatically"));
 	servlist_create_check (4, !(net->flags & FLAG_USE_PROXY), table3, 2, 0, _("Bypass proxy server"));
 	check = servlist_create_check (2, net->flags & FLAG_USE_SSL, table3, 3, 0, _("Use SSL for all the servers on this network"));
@@ -1854,7 +1906,7 @@ servlist_open_edit (GtkWidget *parent, ircnet *net)
 	g_signal_connect (G_OBJECT (button10), "clicked",
 							G_CALLBACK (servlist_edit_close_cb), 0);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox4), button10);
-	GTK_WIDGET_SET_FLAGS (button10, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button10, TRUE);
 
 	if (net->flags & FLAG_USE_GLOBAL)
 	{
@@ -1917,7 +1969,6 @@ servlist_open_networks (void)
 	gtk_container_set_border_width (GTK_CONTAINER (servlist), 4);
 	gtk_window_set_title (GTK_WINDOW (servlist), _(DISPLAY_NAME": Network List"));
 	gtk_window_set_default_size (GTK_WINDOW (servlist), netlist_win_width, netlist_win_height);
-	gtk_window_set_position (GTK_WINDOW (servlist), GTK_WIN_POS_MOUSE);
 	gtk_window_set_role (GTK_WINDOW (servlist), "servlist");
 	gtk_window_set_type_hint (GTK_WINDOW (servlist), GDK_WINDOW_TYPE_HINT_DIALOG);
 	if (current_sess)
@@ -2089,38 +2140,38 @@ servlist_open_networks (void)
 							G_CALLBACK (servlist_addnet_cb), networks_tree);
 	gtk_widget_show (button_add);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox2), button_add);
-	GTK_WIDGET_SET_FLAGS (button_add, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button_add, TRUE);
 
 	button_remove = gtk_button_new_from_stock ("gtk-remove");
 	g_signal_connect (G_OBJECT (button_remove), "clicked",
 							G_CALLBACK (servlist_deletenet_cb), 0);
 	gtk_widget_show (button_remove);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox2), button_remove);
-	GTK_WIDGET_SET_FLAGS (button_remove, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button_remove, TRUE);
 
 	button_edit = gtk_button_new_with_mnemonic (_("_Edit..."));
 	g_signal_connect (G_OBJECT (button_edit), "clicked",
 							G_CALLBACK (servlist_edit_cb), 0);
 	gtk_widget_show (button_edit);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox2), button_edit);
-	GTK_WIDGET_SET_FLAGS (button_edit, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button_edit, TRUE);
 
 	button_sort = gtk_button_new_with_mnemonic (_("_Sort"));
-	add_tip (button_sort, _("Sorts the network list in alphabetical order. "
+	gtk_widget_set_tooltip_text (button_sort, _("Sorts the network list in alphabetical order. "
 				"Use SHIFT-UP and SHIFT-DOWN keys to move a row."));
 	g_signal_connect (G_OBJECT (button_sort), "clicked",
 							G_CALLBACK (servlist_sort), 0);
 	gtk_widget_show (button_sort);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox2), button_sort);
-	GTK_WIDGET_SET_FLAGS (button_sort, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button_sort, TRUE);
 
 	button_sort = gtk_button_new_with_mnemonic (_("_Favor"));
-	add_tip (button_sort, _("Mark or unmark this network as a favorite."));
+	gtk_widget_set_tooltip_text (button_sort, _("Mark or unmark this network as a favorite."));
 	g_signal_connect (G_OBJECT (button_sort), "clicked",
 							G_CALLBACK (servlist_favor), 0);
 	gtk_widget_show (button_sort);
 	gtk_container_add (GTK_CONTAINER (vbuttonbox2), button_sort);
-	GTK_WIDGET_SET_FLAGS (button_sort, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button_sort, TRUE);
 
 	hseparator1 = gtk_hseparator_new ();
 	gtk_widget_show (hseparator1);
@@ -2136,11 +2187,18 @@ servlist_open_networks (void)
 	g_signal_connect (G_OBJECT (button_close), "clicked",
 							G_CALLBACK (servlist_close_cb), 0);
 	gtk_container_add (GTK_CONTAINER (hbuttonbox1), button_close);
-	GTK_WIDGET_SET_FLAGS (button_close, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button_close, TRUE);
 
 	button_connect = gtkutil_button (hbuttonbox1, GTK_STOCK_CONNECT, NULL,
 												servlist_connect_cb, NULL, _("C_onnect"));
-	GTK_WIDGET_SET_FLAGS (button_connect, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default (button_connect, TRUE);
+
+	g_signal_connect (G_OBJECT (entry_guser), "changed", 
+					G_CALLBACK(servlist_username_changed_cb), button_connect);
+	g_signal_connect (G_OBJECT (entry_nick1), "changed",
+					G_CALLBACK(servlist_nick_changed_cb), button_connect);
+	g_signal_connect (G_OBJECT (entry_nick2), "changed",
+					G_CALLBACK(servlist_nick_changed_cb), button_connect);
 
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label3), entry1);
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label6), entry4);
